*********
Nengo SPA
*********

Nengo SPA is an implementation of the Semantic Pointer Architecture for Nengo.
The :doc:`Semantic Pointer Architecture <user_guide/spa_intro>` provides an
approach to building cognitive models implemented with large-scale spiking
neural networks.


.. toctree::
   :maxdepth: 2

   getting_started
   user_guide
   examples
   api
   developer
